@@ -1,7 +1,7 @@
 #!/usr/bin/python
 ########################################################################################################################
 #
-# Copyright (c) 2014, Regents of the University of California
+# Copyright (c) 2020, Nifty Chips Laboratory, Hanyang University
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
@@ -23,14 +23,16 @@
 ########################################################################################################################
 
 """
-The physical module implements classes for various physical layout objects.
-The types of objects supported are summarized below:
+**laygo2.object.physical** module is defining classes for physical objects that 
+compose actual IC layout.
 
-:obj:`PhysicalObject` - a base class for physical layout objects.
+The types of objects supported by the physical module are summarized below:
 
-:obj:`IterablePhysicalObject` - a base class for iterable physical objects (eg. arrayed instances).
+:obj:`PhysicalObject` - base class for physical layout objects.
 
-:obj:`PhysicalObjectGroup` - defines a group of physical objects.
+:obj:`IterablePhysicalObject` - base class for iterable physical objects (eg. arrayed instances).
+
+:obj:`PhysicalObjectGroup` - defines a group of physical objects (not implemented yet).
 
 :obj:`Rect` - defines a rect.
 
@@ -42,8 +44,16 @@ The types of objects supported are summarized below:
 
 :obj:`Instance` - defines an instance.
 
-:obj:`VirtualInstance` - defines a virtual instance composed of multiple physical objects.
+:obj:`VirtualInstance` - defines a virtual instance composed of multiple physical objects
+(a group of objects that acts as a single instance).
 
+The following figure illustrates examples of the physical objects supported by this module.
+
+.. image:: ../assets/img/user_guide_physical.png
+
+
+
+Check the following links for the details of component classes.
 """
 
 __author__ = "Jaeduk Han"
@@ -51,7 +61,6 @@ __maintainer__ = "Jaeduk Han"
 __status__ = "Prototype"
 
 import numpy as np
-
 # from copy import deepcopy
 import laygo2.util.transform as tf
 
@@ -1583,6 +1592,32 @@ class Instance(IterablePhysicalObject):
     """
     Instance object class.
 
+    Example
+    -------
+    >>> import laygo2
+    >>> inst0_pins = dict() 
+    >>> inst0_pins['in'] = laygo2.object.physical.Pin(xy=[[0, 0], [10,10]], 
+            layer = ['M1', 'drawing'], netname = 'in') 
+    >>> inst0_pins['out']= laygo2.object.physical.Pin(xy=[[90, 90], [100, 100]], 
+            layer=['M1', 'drawing'], netname='out')
+    >>> inst0 = laygo2.object.physical.Instance(name="I0", xy=[100,100], 
+            libname="mylib", cellname="mycell", shape=[3, 2], pitch=[200,200], 
+            unit_size=[100, 100], pins=inst0_pins, transform='R0')  
+    >>> print(inst0)
+    <laygo2.object.physical.Instance object at 0x000001AF458AF8E0> 
+        name: I0,
+        class: Instance,
+        xy: [100, 100],
+        params: None,
+        size: [500, 300],
+        shape: [3, 2],
+        pitch: [200, 200],
+        transform: R0,
+        pins: {'in': <laygo2.object.physical.Pin object at 0x000001AF560D6170>, 
+               'out': <laygo2.object.physical.Pin object at 0x000001AF560D5F30>}, 
+    >>> print( inst0[1,0].xy0 )
+    array([300, 100])
+
     Notes
     -----
     **(Korean)**: Instance 객체 클래스.
@@ -2061,6 +2096,18 @@ class Instance(IterablePhysicalObject):
         >>> inst0 = laygo2.object.physical.Instance(name="I0", xy=[100,100], 
                 libname="mylib", cellname="mycell", shape=[3, 2], pitch=[200,200], 
                 unit_size=[100, 100], pins=inst0_pins, transform='R0')   
+        >>> print(inst0)
+        <laygo2.object.physical.Instance object at 0x000001AF458AF8E0> 
+            name: I0,
+            class: Instance,
+            xy: [100, 100],
+            params: None,
+            size: [500, 300],
+            shape: [3, 2],
+            pitch: [200, 200],
+            transform: R0,
+            pins: {'in': <laygo2.object.physical.Pin object at 0x000001AF560D6170>, 
+                   'out': <laygo2.object.physical.Pin object at 0x000001AF560D5F30>}, 
         >>> print( inst0[1,0].xy0 )
         array([300, 100])
 
